@@ -1,4 +1,7 @@
-if (requireNamespace("chromVAR", quietly = TRUE)) {
+skip_if_not_installed("chromVAR")
+skip_if_not_installed("BSgenome.Hsapiens.UCSC.hg19")
+if (requireNamespace("chromVAR", quietly = TRUE) & 
+    requireNamespace("BSgenome.Hsapiens.UCSC.hg19", quietly = TRUE)) {
   test_that("combineSampleTileMatrix works on a 3-sample dataset", {
     cellPopulations <- c("C2", "C3")
     capture.output(
