@@ -14,7 +14,8 @@ skip_on_cran()
 # Working dir during tests is under structure:
 # parent_dir/MOCHA/tests/testthat/. Assumes PBMCSmall is under 'parent_dir'
 ArchRProjDir <- "../../../PBMCSmall"
-if (dir.exists(ArchRProjDir)) {
+if (dir.exists(ArchRProjDir) &&
+    require("purrr", quietly = TRUE)) {
   # Load ArchR project
   capture.output(testProj <- ArchR::loadArchRProject(ArchRProjDir), type = "message")
   cellPopLabel <- "Clusters" # Column with cell population groups
